PlayerProxy

Struct PlayerProxy 

pub struct PlayerProxy<'p>(/* private fields */);
Proxy for the org.mpris.MediaPlayer2.Player interface.

Implementations

Source

impl<'p> PlayerProxy<'p>

pub async fn new<D>( conn: &Connection, destination: D, ) -> Result<PlayerProxy<'p>>
where D: TryInto<BusName<'p>>, D::Error: Into<Error>,

Creates a new proxy with the given destination, and the default path.

pub fn builder(conn: &Connection) -> Builder<'p, Self>

Returns a customizable builder for this proxy.

pub fn into_inner(self) -> Proxy<'p>

Consumes self, returning the underlying zbus::Proxy.

pub fn inner(&self) -> &Proxy<'p>

The reference to the underlying zbus::Proxy.

pub fn inner_mut(&mut self) -> &mut Proxy<'p>

The mutable reference to the underlying zbus::Proxy.

pub async fn next(&self) -> Result<()>

Next method

pub async fn previous(&self) -> Result<()>

Previous method

pub async fn pause(&self) -> Result<()>

Pause method

pub async fn play_pause(&self) -> Result<()>

PlayPause method

pub async fn stop(&self) -> Result<()>

Stop method

pub async fn play(&self) -> Result<()>

Play method

pub async fn seek(&self, offset: MprisDuration) -> Result<()>

Seek method

pub async fn set_position( &self, track_id: TrackId, position: MprisDuration, ) -> Result<()>

SetPosition method

pub async fn open_uri(&self, uri: &str) -> Result<()>

OpenUri method

pub async fn receive_seeked(&self) -> Result<SeekedStream>

Create a stream that receives Seeked signals.

This a convenient wrapper around zbus::Proxy::receive_signal. Seeked signal

Indicates that the track position has changed in a way that is inconsistent with the current playing state.

This signal does not need to be emitted when playback starts or when the track changes, unless the track is starting at an unexpected position. An expected position would be the last known one when going from Paused to Playing, and 0 when going from Stopped to Playing.

pub async fn receive_seeked_with_args( &self, args: &[(u8, &str)], ) -> Result<SeekedStream>

Create a stream that receives Seeked signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. Seeked signal

Indicates that the track position has changed in a way that is inconsistent with the current playing state.

This signal does not need to be emitted when playback starts or when the track changes, unless the track is starting at an unexpected position. An expected position would be the last known one when going from Paused to Playing, and 0 when going from Stopped to Playing.

pub async fn playback_status(&self) -> Result<PlaybackStatus>

PlaybackStatus property

pub fn cached_playback_status( &self, ) -> Result<Option<<Result<PlaybackStatus> as ResultAdapter>::Ok>, <Result<PlaybackStatus> as ResultAdapter>::Err>

PlaybackStatus property Get the cached value of the PlaybackStatus property, or None if the property is not cached.

pub async fn receive_playback_status_changed( &self, ) -> PropertyStream<'p, <Result<PlaybackStatus> as ResultAdapter>::Ok>

PlaybackStatus property Create a stream for the PlaybackStatus property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn loop_status(&self) -> Result<LoopStatus>

LoopStatus property

pub fn cached_loop_status( &self, ) -> Result<Option<<Result<LoopStatus> as ResultAdapter>::Ok>, <Result<LoopStatus> as ResultAdapter>::Err>

LoopStatus property Get the cached value of the LoopStatus property, or None if the property is not cached.

pub async fn receive_loop_status_changed( &self, ) -> PropertyStream<'p, <Result<LoopStatus> as ResultAdapter>::Ok>

LoopStatus property Create a stream for the LoopStatus property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn set_loop_status(&self, value: LoopStatus) -> Result<()>

pub async fn rate(&self) -> Result<f64>

Rate property

pub fn cached_rate( &self, ) -> Result<Option<<Result<f64> as ResultAdapter>::Ok>, <Result<f64> as ResultAdapter>::Err>

Rate property Get the cached value of the Rate property, or None if the property is not cached.

pub async fn receive_rate_changed( &self, ) -> PropertyStream<'p, <Result<f64> as ResultAdapter>::Ok>

Rate property Create a stream for the Rate property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn set_rate(&self, value: f64) -> Result<()>

pub async fn shuffle(&self) -> Result<bool>

Shuffle property

pub fn cached_shuffle( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Shuffle property Get the cached value of the Shuffle property, or None if the property is not cached.

pub async fn receive_shuffle_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

Shuffle property Create a stream for the Shuffle property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn set_shuffle(&self, value: bool) -> Result<()>

pub async fn metadata(&self) -> Result<Metadata>

Metadata property

pub fn cached_metadata( &self, ) -> Result<Option<<Result<Metadata> as ResultAdapter>::Ok>, <Result<Metadata> as ResultAdapter>::Err>

Metadata property Get the cached value of the Metadata property, or None if the property is not cached.

pub async fn receive_metadata_changed( &self, ) -> PropertyStream<'p, <Result<Metadata> as ResultAdapter>::Ok>

Metadata property Create a stream for the Metadata property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn volume(&self) -> Result<f64>

Volume property

pub fn cached_volume( &self, ) -> Result<Option<<Result<f64> as ResultAdapter>::Ok>, <Result<f64> as ResultAdapter>::Err>

Volume property Get the cached value of the Volume property, or None if the property is not cached.

pub async fn receive_volume_changed( &self, ) -> PropertyStream<'p, <Result<f64> as ResultAdapter>::Ok>

Volume property Create a stream for the Volume property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn set_volume(&self, value: f64) -> Result<()>

pub async fn position(&self) -> Result<MprisDuration>

Position property

pub async fn minimum_rate(&self) -> Result<f64>

MinimumRate property

pub fn cached_minimum_rate( &self, ) -> Result<Option<<Result<f64> as ResultAdapter>::Ok>, <Result<f64> as ResultAdapter>::Err>

MinimumRate property Get the cached value of the MinimumRate property, or None if the property is not cached.

pub async fn receive_minimum_rate_changed( &self, ) -> PropertyStream<'p, <Result<f64> as ResultAdapter>::Ok>

MinimumRate property Create a stream for the MinimumRate property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn maximum_rate(&self) -> Result<f64>

MaximumRate property

pub fn cached_maximum_rate( &self, ) -> Result<Option<<Result<f64> as ResultAdapter>::Ok>, <Result<f64> as ResultAdapter>::Err>

MaximumRate property Get the cached value of the MaximumRate property, or None if the property is not cached.

pub async fn receive_maximum_rate_changed( &self, ) -> PropertyStream<'p, <Result<f64> as ResultAdapter>::Ok>

MaximumRate property Create a stream for the MaximumRate property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn can_go_next(&self) -> Result<bool>

CanGoNext property

pub fn cached_can_go_next( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

CanGoNext property Get the cached value of the CanGoNext property, or None if the property is not cached.

pub async fn receive_can_go_next_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

CanGoNext property Create a stream for the CanGoNext property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn can_go_previous(&self) -> Result<bool>

CanGoPrevious property

pub fn cached_can_go_previous( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

CanGoPrevious property Get the cached value of the CanGoPrevious property, or None if the property is not cached.

pub async fn receive_can_go_previous_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

CanGoPrevious property Create a stream for the CanGoPrevious property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn can_play(&self) -> Result<bool>

CanPlay property

pub fn cached_can_play( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

CanPlay property Get the cached value of the CanPlay property, or None if the property is not cached.

pub async fn receive_can_play_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

CanPlay property Create a stream for the CanPlay property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn can_pause(&self) -> Result<bool>

CanPause property

pub fn cached_can_pause( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

CanPause property Get the cached value of the CanPause property, or None if the property is not cached.

pub async fn receive_can_pause_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

CanPause property Create a stream for the CanPause property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn can_seek(&self) -> Result<bool>

CanSeek property

pub fn cached_can_seek( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

CanSeek property Get the cached value of the CanSeek property, or None if the property is not cached.

pub async fn receive_can_seek_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

CanSeek property Create a stream for the CanSeek property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn can_control(&self) -> Result<bool>

CanControl property