pub enum EnumeratorEvent {
Add(OwnedBusName),
Remove(OwnedBusName),
}Expand description
Returned from Enumerator::receive_changes when an MPRIS player was added or removed.
Variants
Add(OwnedBusName)
MPRIS player with the given bus name was added.
Remove(OwnedBusName)
MPRIS player with the given bus name was removed.