TrackList

Struct TrackList 

pub struct TrackList { /* private fields */ }
Simplified access to the track list of an MPRIS media player.

Implementations

Source

impl TrackList

pub async fn new(connection: &Connection, name: OwnedBusName) -> Result<Self>

Creates a new instance of the org.mpris.MediaPlayer2.TrackList interface.

pub async fn add_track<S: ToString>( &self, uri: S, after: TrackId, set_as_current: bool, ) -> Result<()>

Adds a new track to this track list.

pub async fn get_tracks_metadata<T: AsRef<[TrackId]>>( &self, tracks: T, ) -> Result<Vec<Metadata>>

Gets the metadata of the given tracks.

pub async fn go_to(&self, track: TrackId) -> Result<()>

Goes to the specified track.

pub async fn remove(&self, track: TrackId) -> Result<()>

Removes the specified track.

pub async fn tracks(&self) -> Result<Vec<TrackId>>

Returns a list of all available TrackIds.

pub async fn detailed_tracks(&self) -> Result<BTreeMap<TrackId, Metadata>>

Returns a list of all available TrackIds and their associated metadata, in order.

Methods from Deref<Target = TrackListProxy<'static>>

pub fn inner(&self) -> &Proxy<'p>

The reference to the underlying zbus::Proxy.

pub async fn get_tracks_metadata( &self, track_ids: Vec<TrackId>, ) -> Result<Vec<Metadata>>

GetTracksMetadata method

pub async fn add_track( &self, uri: &str, after_track: TrackId, set_as_current: bool, ) -> Result<()>

AddTrack method

pub async fn remove_track(&self, track_id: TrackId) -> Result<()>

RemoveTrack method

pub async fn go_to(&self, track_id: TrackId) -> Result<()>

GoTo method

pub async fn receive_track_list_replaced( &self, ) -> Result<TrackListReplacedStream>

Create a stream that receives TrackListReplaced signals.

This a convenient wrapper around zbus::Proxy::receive_signal. TrackListReplaced signal

Indicates that the entire tracklist has been replaced.

It is left up to the implementation to decide when a change to the track list is invasive enough that this signal should be emitted instead of a series of TrackAdded and TrackRemoved signals.

/org/mpris/MediaPlayer2/TrackList/NoTrack indicates that there is no current track.

pub async fn receive_track_list_replaced_with_args( &self, args: &[(u8, &str)], ) -> Result<TrackListReplacedStream>

Create a stream that receives TrackListReplaced signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. TrackListReplaced signal

Indicates that the entire tracklist has been replaced.

It is left up to the implementation to decide when a change to the track list is invasive enough that this signal should be emitted instead of a series of TrackAdded and TrackRemoved signals.

/org/mpris/MediaPlayer2/TrackList/NoTrack indicates that there is no current track.

pub async fn receive_track_added(&self) -> Result<TrackAddedStream>

Create a stream that receives TrackAdded signals.

This a convenient wrapper around zbus::Proxy::receive_signal. TrackAdded signal

Indicates that a track has been added to the track list.

pub async fn receive_track_added_with_args( &self, args: &[(u8, &str)], ) -> Result<TrackAddedStream>

Create a stream that receives TrackAdded signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. TrackAdded signal

Indicates that a track has been added to the track list.

pub async fn receive_track_removed(&self) -> Result<TrackRemovedStream>

Create a stream that receives TrackRemoved signals.

This a convenient wrapper around zbus::Proxy::receive_signal. TrackRemoved signal

Indicates that a track has been removed from the track list.

pub async fn receive_track_removed_with_args( &self, args: &[(u8, &str)], ) -> Result<TrackRemovedStream>

Create a stream that receives TrackRemoved signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. TrackRemoved signal

Indicates that a track has been removed from the track list.

pub async fn receive_track_metadata_changed( &self, ) -> Result<TrackMetadataChangedStream>

Create a stream that receives TrackMetadataChanged signals.

This a convenient wrapper around zbus::Proxy::receive_signal. TrackMetadataChanged signal

Indicates that the metadata of a track in the tracklist has changed.

This may indicate that a track has been replaced, in which case the mpris:trackid metadata entry is different from the track argument.

pub async fn receive_track_metadata_changed_with_args( &self, args: &[(u8, &str)], ) -> Result<TrackMetadataChangedStream>

Create a stream that receives TrackMetadataChanged signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. TrackMetadataChanged signal

Indicates that the metadata of a track in the tracklist has changed.

This may indicate that a track has been replaced, in which case the mpris:trackid metadata entry is different from the track argument.

pub async fn tracks(&self) -> Result<Vec<TrackId>>

Tracks property

pub fn cached_tracks( &self, ) -> Result<Option<<Result<Vec<TrackId>> as ResultAdapter>::Ok>, <Result<Vec<TrackId>> as ResultAdapter>::Err>

Tracks property Get the cached value of the Tracks property, or None if the property is not cached.

pub async fn receive_tracks_changed( &self, ) -> PropertyStream<'p, <Result<Vec<TrackId>> as ResultAdapter>::Ok>

Tracks property Create a stream for the Tracks property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn can_edit_tracks(&self) -> Result<bool>

CanEditTracks property

pub fn cached_can_edit_tracks( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

CanEditTracks property Get the cached value of the CanEditTracks property, or None if the property is not cached.

pub async fn receive_can_edit_tracks_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

CanEditTracks property Create a stream for the CanEditTracks property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.