pub enum LoopStatus {
None,
Track,
Playlist,
}Expand description
A repeat / loop status
Variants
None
The playback will stop when there are no more tracks to play.
Track
The current track will start again from the begining once it has finished playing.
Playlist
The playback loops through a list of tracks.